/*
  Copyright (c) 2015-2017 Montel Laurent <montel@kde.org>

  This library is free software; you can redistribute it and/or modify it
  under the terms of the GNU Library General Public License as published by
  the Free Software Foundation; either version 2 of the License, or (at your
  option) any later version.

  This library is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
  License for more details.

  You should have received a copy of the GNU Library General Public License
  along with this library; see the file COPYING.LIB.  If not, write to the
  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
  02110-1301, USA.

*/

#ifndef BLACKLISTBALOOEMAILSEARCHJOB_H
#define BLACKLISTBALOOEMAILSEARCHJOB_H

#include <QObject>

#include "libkdepimakonadi_private_export.h"
namespace KPIM {
class LIBKDEPIMAKONADI_TESTS_EXPORT BlackListBalooEmailSearchJob : public QObject
{
    Q_OBJECT
public:
    explicit BlackListBalooEmailSearchJob(QObject *parent = nullptr);
    ~BlackListBalooEmailSearchJob();

    bool start();

    void setSearchEmail(const QString &searchEmail);

    void setLimit(int limit);

Q_SIGNALS:
    void emailsFound(const QStringList &list);

private:
    QString mSearchEmail;
    int mLimit = 500;
};
}

#endif // BLACKLISTBALOOEMAILSEARCHJOB_H
